@@ -153,34 +153,38 @@ http_response_create_and_send.argtypes = [http_status, c_void_p, c_size_t, c_voi
 http_response_create_and_send.restype = c_uint8
 
 def http_send_response (
-	http_receive, status_code,
-	body, body_len = None,
-	content_type = HTTP_CONTENT_TYPE_HTML
+	http_receive: c_void_p, status_code: http_status,
+	body=None, body_len=None,
+	content_type=HTTP_CONTENT_TYPE_HTML
 ):
 	"""
-	Function to create and send a HTTP response
+	Creates and sends a HTTP response based on the supplied body
 	# Parameters
 	------------
-	### http_receive : HttpReceive
-		The receive structure associated with the current request
-	### status_code : int, optional
-		HTTP status code value
+	### http_receive: HttpReceive
+		Reference to a HTTP receive instance
+	### status_code: http_status
+		The response's status code
 	### body: dict, str, bytes
 		Value(s) to send in the response's body
-	### body_len
-		Size of the body to send. Defaults to None (Will be calculated)
-	### content_type
-		The response's body content type. If body is dict then content_type will be application/json. Defaults to text/html; charset=UTF-8
+	### body_len: int
+		Size of the body to send. If None it will be calculated
+	### content_type: ContentType
+		The response's body content type
 	"""
-	if type (body) is dict:
+	if (type (body) is dict):
 		body_string = json.dumps (body)
 		body_len = len (body_string)
-		http_response_render_json (http_receive, status_code, body_string.encode ("utf-8"), body_len)
+		http_response_render_json (
+			http_receive, status_code,
+			body_string.encode ("utf-8"), body_len
+		)
+
 	else: 
 		real_body = body
-		if type (body) is str:
+		if (type (body) is str):
 			real_body = body.encode ("utf-8")
-		if body_len is None:
+		if (body_len is None):
 			body_len = len (body)
 
 		response = http_response_create (
@@ -188,8 +192,8 @@ def http_send_response (
 		)
 
 		http_response_add_content_type_header (response, content_type)
-
 		http_response_add_content_length_header (response, body_len)
+
 		http_response_compile (response)
 		http_response_send (response, http_receive)
 		http_response_delete (response)
